@@ -5,7 +5,6 @@
 [![NPM](https://img.shields.io/npm/v/datadog-cdk-constructs-v2?color=39a356&label=npm+cdk+v2)](https://www.npmjs.com/package/datadog-cdk-constructs-v2)
 [![PyPI](https://img.shields.io/pypi/v/datadog-cdk-constructs?color=blue&label=pypi+cdk+v1)](https://pypi.org/project/datadog-cdk-constructs/)
 [![PyPI](https://img.shields.io/pypi/v/datadog-cdk-constructs-v2?color=39a356&label=pypi+cdk+v2)](https://pypi.org/project/datadog-cdk-constructs-v2/)
-[![Slack](https://chat.datadoghq.com/badge.svg?bg=632CA6)](https://chat.datadoghq.com/)
 [![License](https://img.shields.io/badge/license-Apache--2.0-blue)](https://github.com/DataDog/datadog-cdk-constructs/blob/main/LICENSE)
 
 Use this Datadog CDK Construct Library to deploy serverless applications using AWS CDK .
@@ -97,9 +96,47 @@ datadog.addLambdaFunctions([<LAMBDA_FUNCTIONS>])
 datadog.addForwarderToNonLambdaLogGroups([<LOG_GROUPS>])
 ```
 
-Optionally, if you'd like to enable [source code integration](https://docs.datadoghq.com/integrations/guide/source-code-integration/) (Typescript only), you'll need to make a few changes to your stack setup since the AWS CDK does not support async functions.
+## Source Code Integration
 
-Change your initialization function as follows (note: we're changing this to pass the `gitHash` value to the CDK):
+[Source code integration](https://docs.datadoghq.com/integrations/guide/source-code-integration/) is enabled by default through automatic lambda tagging, and will work if:
+
+* The Datadog Github Integration is installed.
+* Your datadog-cdk dependency satisfies either of the below versions:
+
+  * `datadog-cdk-constructs-v2` >= 1.4.0
+  * `datadog-cdk-constructs` >= 0.8.5
+
+### Alternative Methods to Enable Source Code Integration
+
+If the automatic implementation doesn't work for your case, please follow one of the two guides below.
+
+**Note: these alternate guides only work for Typescript.**
+
+<details>
+  <summary>datadog-cdk version satisfied, but Datadog Github Integration NOT installed</summary>
+
+If the Datadog Github Integration is not installed, you need to import the `datadog-ci` package and manually upload your Git metadata to Datadog.
+We recommend you do this where your CDK Stack is initialized.
+
+```python
+const app = new cdk.App();
+
+// Make sure to add @datadog/datadog-ci via your package manager
+const datadogCi = require("@datadog/datadog-ci");
+// Manually uploading Git metadata to Datadog.
+datadogCi.gitMetadata.uploadGitCommitHash('{Datadog_API_Key}', '<SITE>')
+
+const app = new cdk.App();
+new ExampleStack(app, "ExampleStack", {});
+
+app.synth();
+```
+
+</details>
+<details>
+  <summary>datadog-cdk version NOT satisfied</summary>
+
+Change your initialization function as follows (note: we're changing this to pass just the `gitHash` value to the CDK):
 
 ```python
 async function main() {
@@ -113,6 +150,8 @@ async function main() {
 }
 ```
 
+Ensure you call this function to initialize your stack.
+
 In your stack constructor, change to add an optional `gitHash` parameter, and call `addGitCommitMetadata()`:
 
 ```python
@@ -125,6 +164,8 @@ export class ExampleStack extends cdk.Stack {
 }
 ```
 
+</details>
+
 ## Configuration
 
 To further configure your Datadog construct, use the following custom parameters:
@@ -147,14 +188,22 @@ To further configure your Datadog construct, use the following custom parameters
 | `enableDatadogTracing` | `enable_datadog_tracing` | Enable Datadog tracing on your Lambda functions. Defaults to `true`. |
 | `enableMergeXrayTraces` | `enable_merge_xray_traces` | Enable merging X-Ray traces on your Lambda functions. Defaults to `false`. |
 | `enableDatadogLogs` | `enable_datadog_logs` | Send Lambda function logs to Datadog via the Datadog Lambda Extension.  Defaults to `true`. Note: This setting has no effect on logs sent via the Datadog Forwarder. |
+| `enableSourceCodeIntegration` | `enable_source_code_integration` | Enable Datadog Source Code Integration, connecting your telemetry with application code in your Git repositories. This requires the Datadog Github Integration to work, otherwise please follow the [alternative method](#alternative-methods-to-enable-source-code-integration). Learn more [here](https://docs.datadoghq.com/integrations/guide/source-code-integration/). Defaults to `true`. |
 | `injectLogContext` | `inject_log_context` | When set, the Lambda layer will automatically patch console.log with Datadog's tracing ids. Defaults to `true`. |
 | `logLevel` | `log_level` | When set to `debug`, the Datadog Lambda Library and Extension will log additional information to help troubleshoot issues. |
 | `env` | `env` | When set along with `extensionLayerVersion`, a `DD_ENV` environment variable is added to all Lambda functions with the provided value. When set along with `forwarderArn`, an `env` tag is added to all Lambda functions with the provided value. |
 | `service` | `service` | When set along with `extensionLayerVersion`, a `DD_SERVICE` environment variable is added to all Lambda functions with the provided value. When set along with `forwarderArn`, a `service` tag is added to all Lambda functions with the provided value. |
 | `version` | `version` | When set along with `extensionLayerVersion`, a `DD_VERSION` environment variable is added to all Lambda functions with the provided value. When set along with `forwarderArn`, a `version` tag is added to all Lambda functions with the provided value. |
 | `tags` | `tags` | A comma separated list of key:value pairs as a single string. When set along with `extensionLayerVersion`, a `DD_TAGS` environment variable is added to all Lambda functions with the provided value. When set along with `forwarderArn`, the cdk parses the string and sets each key:value pair as a tag to all Lambda functions. |
+| `enableColdStartTracing`      | `enable_cold_start_tracing` | Set to `false` to disable Cold Start Tracing. Used in NodeJS and Python. Defaults to `true`. |
+| `coldStartTraceMinDuration`   | `min_cold_start_trace_duration` | Sets the minimum duration (in milliseconds) for a module load event to be traced via Cold Start Tracing. Number. Defaults to `3`. |
+| `coldStartTraceSkipLibs`      | `cold_start_trace_skip_libs`| Optionally skip creating Cold Start Spans for a comma-separated list of libraries. Useful to limit depth or skip known libraries. Default depends on runtime. |
+| `enableProfiling`             | `enable_profiling` | Enable the Datadog Continuous Profiler with `true`. Supported in Beta for NodeJS and Python. Defaults to `false`. |
+| `encodeAuthorizerContext`     |`encode_authorizer_context` | When set to `true` for Lambda authorizers, the tracing context will be encoded into the response for propagation. Supported for NodeJS and Python. Defaults to `true`. |
+| `decodeAuthorizerContext`     |`decode_authorizer_context` | When set to `true` for Lambdas that are authorized via Lambda authorizers, it will parse and use the encoded tracing context (if found). Supported for NodeJS and Python. Defaults to `true`.                         |
+| `apmFlushDeadline` | Used to determine when to submit spans before a timeout occurs, in milliseconds. When the remaining time in an AWS Lambda invocation is less than the value set. The tracer will attempt to submit the current active spans and all finished spans. Supported for NodeJS and Python. Defaults to `100` milliseconds. |
 
-**Note**: `env`, `service`, `version`, and `tags` override function level `DD_XXX` environment variables.
+**Note**: Using the parameters above may override corresponding function level `DD_XXX` environment variables.
 
 ### Tracing
 
@@ -335,21 +384,30 @@ class Datadog(
         api_key: typing.Optional[builtins.str] = None,
         api_key_secret_arn: typing.Optional[builtins.str] = None,
         api_kms_key: typing.Optional[builtins.str] = None,
+        apm_flush_deadline: typing.Optional[typing.Union[builtins.str, jsii.Number]] = None,
         capture_lambda_payload: typing.Optional[builtins.bool] = None,
+        cold_start_trace_skip_libs: typing.Optional[builtins.str] = None,
         create_forwarder_permissions: typing.Optional[builtins.bool] = None,
+        decode_authorizer_context: typing.Optional[builtins.bool] = None,
+        enable_cold_start_tracing: typing.Optional[builtins.bool] = None,
         enable_datadog_logs: typing.Optional[builtins.bool] = None,
         enable_datadog_tracing: typing.Optional[builtins.bool] = None,
         enable_merge_xray_traces: typing.Optional[builtins.bool] = None,
+        enable_profiling: typing.Optional[builtins.bool] = None,
+        encode_authorizer_context: typing.Optional[builtins.bool] = None,
         env: typing.Optional[builtins.str] = None,
         extension_layer_version: typing.Optional[jsii.Number] = None,
         flush_metrics_to_logs: typing.Optional[builtins.bool] = None,
         forwarder_arn: typing.Optional[builtins.str] = None,
         inject_log_context: typing.Optional[builtins.bool] = None,
+        java_layer_version: typing.Optional[jsii.Number] = None,
         log_level: typing.Optional[builtins.str] = None,
+        min_cold_start_trace_duration: typing.Optional[jsii.Number] = None,
         node_layer_version: typing.Optional[jsii.Number] = None,
         python_layer_version: typing.Optional[jsii.Number] = None,
         service: typing.Optional[builtins.str] = None,
         site: typing.Optional[builtins.str] = None,
+        source_code_integration: typing.Optional[builtins.bool] = None,
         tags: typing.Optional[builtins.str] = None,
         version: typing.Optional[builtins.str] = None,
     ) -> None:
@@ -360,21 +418,30 @@ class Datadog(
         :param api_key: 
         :param api_key_secret_arn: 
         :param api_kms_key: 
+        :param apm_flush_deadline: 
         :param capture_lambda_payload: 
+        :param cold_start_trace_skip_libs: 
         :param create_forwarder_permissions: 
+        :param decode_authorizer_context: 
+        :param enable_cold_start_tracing: 
         :param enable_datadog_logs: 
         :param enable_datadog_tracing: 
         :param enable_merge_xray_traces: 
+        :param enable_profiling: 
+        :param encode_authorizer_context: 
         :param env: 
         :param extension_layer_version: 
         :param flush_metrics_to_logs: 
         :param forwarder_arn: 
         :param inject_log_context: 
+        :param java_layer_version: 
         :param log_level: 
+        :param min_cold_start_trace_duration: 
         :param node_layer_version: 
         :param python_layer_version: 
         :param service: 
         :param site: 
+        :param source_code_integration: 
         :param tags: 
         :param version: 
         '''
@@ -387,21 +454,30 @@ class Datadog(
             api_key=api_key,
             api_key_secret_arn=api_key_secret_arn,
             api_kms_key=api_kms_key,
+            apm_flush_deadline=apm_flush_deadline,
             capture_lambda_payload=capture_lambda_payload,
+            cold_start_trace_skip_libs=cold_start_trace_skip_libs,
             create_forwarder_permissions=create_forwarder_permissions,
+            decode_authorizer_context=decode_authorizer_context,
+            enable_cold_start_tracing=enable_cold_start_tracing,
             enable_datadog_logs=enable_datadog_logs,
             enable_datadog_tracing=enable_datadog_tracing,
             enable_merge_xray_traces=enable_merge_xray_traces,
+            enable_profiling=enable_profiling,
+            encode_authorizer_context=encode_authorizer_context,
             env=env,
             extension_layer_version=extension_layer_version,
             flush_metrics_to_logs=flush_metrics_to_logs,
             forwarder_arn=forwarder_arn,
             inject_log_context=inject_log_context,
+            java_layer_version=java_layer_version,
             log_level=log_level,
+            min_cold_start_trace_duration=min_cold_start_trace_duration,
             node_layer_version=node_layer_version,
             python_layer_version=python_layer_version,
             service=service,
             site=site,
+            source_code_integration=source_code_integration,
             tags=tags,
             version=version,
         )
@@ -425,17 +501,20 @@ class Datadog(
     def add_git_commit_metadata(
         self,
         lambda_functions: typing.Sequence[typing.Union[_aws_cdk_aws_lambda_ceddda9d.Function, _aws_cdk_aws_lambda_nodejs_ceddda9d.NodejsFunction, _aws_cdk_aws_lambda_python_alpha_49328424.PythonFunction]],
-        git_commit_sha: builtins.str,
+        git_commit_sha: typing.Optional[builtins.str] = None,
+        git_repo_url: typing.Optional[builtins.str] = None,
     ) -> None:
         '''
         :param lambda_functions: -
         :param git_commit_sha: -
+        :param git_repo_url: -
         '''
         if __debug__:
             type_hints = typing.get_type_hints(_typecheckingstub__313fba2a998cdf3ba070c09b0db7a32884ad3e5a7bb9eeaf8861202b45695e8e)
             check_type(argname="argument lambda_functions", value=lambda_functions, expected_type=type_hints["lambda_functions"])
             check_type(argname="argument git_commit_sha", value=git_commit_sha, expected_type=type_hints["git_commit_sha"])
-        return typing.cast(None, jsii.invoke(self, "addGitCommitMetadata", [lambda_functions, git_commit_sha]))
+            check_type(argname="argument git_repo_url", value=git_repo_url, expected_type=type_hints["git_repo_url"])
+        return typing.cast(None, jsii.invoke(self, "addGitCommitMetadata", [lambda_functions, git_commit_sha, git_repo_url]))
 
     @jsii.member(jsii_name="addLambdaFunctions")
     def add_lambda_functions(
@@ -495,21 +574,30 @@ class Datadog(
         "api_key": "apiKey",
         "api_key_secret_arn": "apiKeySecretArn",
         "api_kms_key": "apiKmsKey",
+        "apm_flush_deadline": "apmFlushDeadline",
         "capture_lambda_payload": "captureLambdaPayload",
+        "cold_start_trace_skip_libs": "coldStartTraceSkipLibs",
         "create_forwarder_permissions": "createForwarderPermissions",
+        "decode_authorizer_context": "decodeAuthorizerContext",
+        "enable_cold_start_tracing": "enableColdStartTracing",
         "enable_datadog_logs": "enableDatadogLogs",
         "enable_datadog_tracing": "enableDatadogTracing",
         "enable_merge_xray_traces": "enableMergeXrayTraces",
+        "enable_profiling": "enableProfiling",
+        "encode_authorizer_context": "encodeAuthorizerContext",
         "env": "env",
         "extension_layer_version": "extensionLayerVersion",
         "flush_metrics_to_logs": "flushMetricsToLogs",
         "forwarder_arn": "forwarderArn",
         "inject_log_context": "injectLogContext",
+        "java_layer_version": "javaLayerVersion",
         "log_level": "logLevel",
+        "min_cold_start_trace_duration": "minColdStartTraceDuration",
         "node_layer_version": "nodeLayerVersion",
         "python_layer_version": "pythonLayerVersion",
         "service": "service",
         "site": "site",
+        "source_code_integration": "sourceCodeIntegration",
         "tags": "tags",
         "version": "version",
     },
@@ -522,21 +610,30 @@ class DatadogProps:
         api_key: typing.Optional[builtins.str] = None,
         api_key_secret_arn: typing.Optional[builtins.str] = None,
         api_kms_key: typing.Optional[builtins.str] = None,
+        apm_flush_deadline: typing.Optional[typing.Union[builtins.str, jsii.Number]] = None,
         capture_lambda_payload: typing.Optional[builtins.bool] = None,
+        cold_start_trace_skip_libs: typing.Optional[builtins.str] = None,
         create_forwarder_permissions: typing.Optional[builtins.bool] = None,
+        decode_authorizer_context: typing.Optional[builtins.bool] = None,
+        enable_cold_start_tracing: typing.Optional[builtins.bool] = None,
         enable_datadog_logs: typing.Optional[builtins.bool] = None,
         enable_datadog_tracing: typing.Optional[builtins.bool] = None,
         enable_merge_xray_traces: typing.Optional[builtins.bool] = None,
+        enable_profiling: typing.Optional[builtins.bool] = None,
+        encode_authorizer_context: typing.Optional[builtins.bool] = None,
         env: typing.Optional[builtins.str] = None,
         extension_layer_version: typing.Optional[jsii.Number] = None,
         flush_metrics_to_logs: typing.Optional[builtins.bool] = None,
         forwarder_arn: typing.Optional[builtins.str] = None,
         inject_log_context: typing.Optional[builtins.bool] = None,
+        java_layer_version: typing.Optional[jsii.Number] = None,
         log_level: typing.Optional[builtins.str] = None,
+        min_cold_start_trace_duration: typing.Optional[jsii.Number] = None,
         node_layer_version: typing.Optional[jsii.Number] = None,
         python_layer_version: typing.Optional[jsii.Number] = None,
         service: typing.Optional[builtins.str] = None,
         site: typing.Optional[builtins.str] = None,
+        source_code_integration: typing.Optional[builtins.bool] = None,
         tags: typing.Optional[builtins.str] = None,
         version: typing.Optional[builtins.str] = None,
     ) -> None:
@@ -545,21 +642,30 @@ class DatadogProps:
         :param api_key: 
         :param api_key_secret_arn: 
         :param api_kms_key: 
+        :param apm_flush_deadline: 
         :param capture_lambda_payload: 
+        :param cold_start_trace_skip_libs: 
         :param create_forwarder_permissions: 
+        :param decode_authorizer_context: 
+        :param enable_cold_start_tracing: 
         :param enable_datadog_logs: 
         :param enable_datadog_tracing: 
         :param enable_merge_xray_traces: 
+        :param enable_profiling: 
+        :param encode_authorizer_context: 
         :param env: 
         :param extension_layer_version: 
         :param flush_metrics_to_logs: 
         :param forwarder_arn: 
         :param inject_log_context: 
+        :param java_layer_version: 
         :param log_level: 
+        :param min_cold_start_trace_duration: 
         :param node_layer_version: 
         :param python_layer_version: 
         :param service: 
         :param site: 
+        :param source_code_integration: 
         :param tags: 
         :param version: 
         '''
@@ -569,21 +675,30 @@ class DatadogProps:
             check_type(argname="argument api_key", value=api_key, expected_type=type_hints["api_key"])
             check_type(argname="argument api_key_secret_arn", value=api_key_secret_arn, expected_type=type_hints["api_key_secret_arn"])
             check_type(argname="argument api_kms_key", value=api_kms_key, expected_type=type_hints["api_kms_key"])
+            check_type(argname="argument apm_flush_deadline", value=apm_flush_deadline, expected_type=type_hints["apm_flush_deadline"])
             check_type(argname="argument capture_lambda_payload", value=capture_lambda_payload, expected_type=type_hints["capture_lambda_payload"])
+            check_type(argname="argument cold_start_trace_skip_libs", value=cold_start_trace_skip_libs, expected_type=type_hints["cold_start_trace_skip_libs"])
             check_type(argname="argument create_forwarder_permissions", value=create_forwarder_permissions, expected_type=type_hints["create_forwarder_permissions"])
+            check_type(argname="argument decode_authorizer_context", value=decode_authorizer_context, expected_type=type_hints["decode_authorizer_context"])
+            check_type(argname="argument enable_cold_start_tracing", value=enable_cold_start_tracing, expected_type=type_hints["enable_cold_start_tracing"])
             check_type(argname="argument enable_datadog_logs", value=enable_datadog_logs, expected_type=type_hints["enable_datadog_logs"])
             check_type(argname="argument enable_datadog_tracing", value=enable_datadog_tracing, expected_type=type_hints["enable_datadog_tracing"])
             check_type(argname="argument enable_merge_xray_traces", value=enable_merge_xray_traces, expected_type=type_hints["enable_merge_xray_traces"])
+            check_type(argname="argument enable_profiling", value=enable_profiling, expected_type=type_hints["enable_profiling"])
+            check_type(argname="argument encode_authorizer_context", value=encode_authorizer_context, expected_type=type_hints["encode_authorizer_context"])
             check_type(argname="argument env", value=env, expected_type=type_hints["env"])
             check_type(argname="argument extension_layer_version", value=extension_layer_version, expected_type=type_hints["extension_layer_version"])
             check_type(argname="argument flush_metrics_to_logs", value=flush_metrics_to_logs, expected_type=type_hints["flush_metrics_to_logs"])
             check_type(argname="argument forwarder_arn", value=forwarder_arn, expected_type=type_hints["forwarder_arn"])
             check_type(argname="argument inject_log_context", value=inject_log_context, expected_type=type_hints["inject_log_context"])
+            check_type(argname="argument java_layer_version", value=java_layer_version, expected_type=type_hints["java_layer_version"])
             check_type(argname="argument log_level", value=log_level, expected_type=type_hints["log_level"])
+            check_type(argname="argument min_cold_start_trace_duration", value=min_cold_start_trace_duration, expected_type=type_hints["min_cold_start_trace_duration"])
             check_type(argname="argument node_layer_version", value=node_layer_version, expected_type=type_hints["node_layer_version"])
             check_type(argname="argument python_layer_version", value=python_layer_version, expected_type=type_hints["python_layer_version"])
             check_type(argname="argument service", value=service, expected_type=type_hints["service"])
             check_type(argname="argument site", value=site, expected_type=type_hints["site"])
+            check_type(argname="argument source_code_integration", value=source_code_integration, expected_type=type_hints["source_code_integration"])
             check_type(argname="argument tags", value=tags, expected_type=type_hints["tags"])
             check_type(argname="argument version", value=version, expected_type=type_hints["version"])
         self._values: typing.Dict[builtins.str, typing.Any] = {}
@@ -595,16 +710,28 @@ class DatadogProps:
             self._values["api_key_secret_arn"] = api_key_secret_arn
         if api_kms_key is not None:
             self._values["api_kms_key"] = api_kms_key
+        if apm_flush_deadline is not None:
+            self._values["apm_flush_deadline"] = apm_flush_deadline
         if capture_lambda_payload is not None:
             self._values["capture_lambda_payload"] = capture_lambda_payload
+        if cold_start_trace_skip_libs is not None:
+            self._values["cold_start_trace_skip_libs"] = cold_start_trace_skip_libs
         if create_forwarder_permissions is not None:
             self._values["create_forwarder_permissions"] = create_forwarder_permissions
+        if decode_authorizer_context is not None:
+            self._values["decode_authorizer_context"] = decode_authorizer_context
+        if enable_cold_start_tracing is not None:
+            self._values["enable_cold_start_tracing"] = enable_cold_start_tracing
         if enable_datadog_logs is not None:
             self._values["enable_datadog_logs"] = enable_datadog_logs
         if enable_datadog_tracing is not None:
             self._values["enable_datadog_tracing"] = enable_datadog_tracing
         if enable_merge_xray_traces is not None:
             self._values["enable_merge_xray_traces"] = enable_merge_xray_traces
+        if enable_profiling is not None:
+            self._values["enable_profiling"] = enable_profiling
+        if encode_authorizer_context is not None:
+            self._values["encode_authorizer_context"] = encode_authorizer_context
         if env is not None:
             self._values["env"] = env
         if extension_layer_version is not None:
@@ -615,8 +742,12 @@ class DatadogProps:
             self._values["forwarder_arn"] = forwarder_arn
         if inject_log_context is not None:
             self._values["inject_log_context"] = inject_log_context
+        if java_layer_version is not None:
+            self._values["java_layer_version"] = java_layer_version
         if log_level is not None:
             self._values["log_level"] = log_level
+        if min_cold_start_trace_duration is not None:
+            self._values["min_cold_start_trace_duration"] = min_cold_start_trace_duration
         if node_layer_version is not None:
             self._values["node_layer_version"] = node_layer_version
         if python_layer_version is not None:
@@ -625,6 +756,8 @@ class DatadogProps:
             self._values["service"] = service
         if site is not None:
             self._values["site"] = site
+        if source_code_integration is not None:
+            self._values["source_code_integration"] = source_code_integration
         if tags is not None:
             self._values["tags"] = tags
         if version is not None:
@@ -650,16 +783,38 @@ class DatadogProps:
         result = self._values.get("api_kms_key")
         return typing.cast(typing.Optional[builtins.str], result)
 
+    @builtins.property
+    def apm_flush_deadline(
+        self,
+    ) -> typing.Optional[typing.Union[builtins.str, jsii.Number]]:
+        result = self._values.get("apm_flush_deadline")
+        return typing.cast(typing.Optional[typing.Union[builtins.str, jsii.Number]], result)
+
     @builtins.property
     def capture_lambda_payload(self) -> typing.Optional[builtins.bool]:
         result = self._values.get("capture_lambda_payload")
         return typing.cast(typing.Optional[builtins.bool], result)
 
+    @builtins.property
+    def cold_start_trace_skip_libs(self) -> typing.Optional[builtins.str]:
+        result = self._values.get("cold_start_trace_skip_libs")
+        return typing.cast(typing.Optional[builtins.str], result)
+
     @builtins.property
     def create_forwarder_permissions(self) -> typing.Optional[builtins.bool]:
         result = self._values.get("create_forwarder_permissions")
         return typing.cast(typing.Optional[builtins.bool], result)
 
+    @builtins.property
+    def decode_authorizer_context(self) -> typing.Optional[builtins.bool]:
+        result = self._values.get("decode_authorizer_context")
+        return typing.cast(typing.Optional[builtins.bool], result)
+
+    @builtins.property
+    def enable_cold_start_tracing(self) -> typing.Optional[builtins.bool]:
+        result = self._values.get("enable_cold_start_tracing")
+        return typing.cast(typing.Optional[builtins.bool], result)
+
     @builtins.property
     def enable_datadog_logs(self) -> typing.Optional[builtins.bool]:
         result = self._values.get("enable_datadog_logs")
@@ -675,6 +830,16 @@ class DatadogProps:
         result = self._values.get("enable_merge_xray_traces")
         return typing.cast(typing.Optional[builtins.bool], result)
 
+    @builtins.property
+    def enable_profiling(self) -> typing.Optional[builtins.bool]:
+        result = self._values.get("enable_profiling")
+        return typing.cast(typing.Optional[builtins.bool], result)
+
+    @builtins.property
+    def encode_authorizer_context(self) -> typing.Optional[builtins.bool]:
+        result = self._values.get("encode_authorizer_context")
+        return typing.cast(typing.Optional[builtins.bool], result)
+
     @builtins.property
     def env(self) -> typing.Optional[builtins.str]:
         result = self._values.get("env")
@@ -700,11 +865,21 @@ class DatadogProps:
         result = self._values.get("inject_log_context")
         return typing.cast(typing.Optional[builtins.bool], result)
 
+    @builtins.property
+    def java_layer_version(self) -> typing.Optional[jsii.Number]:
+        result = self._values.get("java_layer_version")
+        return typing.cast(typing.Optional[jsii.Number], result)
+
     @builtins.property
     def log_level(self) -> typing.Optional[builtins.str]:
         result = self._values.get("log_level")
         return typing.cast(typing.Optional[builtins.str], result)
 
+    @builtins.property
+    def min_cold_start_trace_duration(self) -> typing.Optional[jsii.Number]:
+        result = self._values.get("min_cold_start_trace_duration")
+        return typing.cast(typing.Optional[jsii.Number], result)
+
     @builtins.property
     def node_layer_version(self) -> typing.Optional[jsii.Number]:
         result = self._values.get("node_layer_version")
@@ -725,6 +900,11 @@ class DatadogProps:
         result = self._values.get("site")
         return typing.cast(typing.Optional[builtins.str], result)
 
+    @builtins.property
+    def source_code_integration(self) -> typing.Optional[builtins.bool]:
+        result = self._values.get("source_code_integration")
+        return typing.cast(typing.Optional[builtins.bool], result)
+
     @builtins.property
     def tags(self) -> typing.Optional[builtins.str]:
         result = self._values.get("tags")
@@ -763,10 +943,12 @@ class DatadogProps:
         "extension_layer_version": "extensionLayerVersion",
         "flush_metrics_to_logs": "flushMetricsToLogs",
         "forwarder_arn": "forwarderArn",
+        "java_layer_version": "javaLayerVersion",
         "log_level": "logLevel",
         "node_layer_version": "nodeLayerVersion",
         "python_layer_version": "pythonLayerVersion",
         "site": "site",
+        "source_code_integration": "sourceCodeIntegration",
     },
 )
 class DatadogStrictProps:
@@ -785,10 +967,12 @@ class DatadogStrictProps:
         extension_layer_version: typing.Optional[jsii.Number] = None,
         flush_metrics_to_logs: typing.Optional[builtins.bool] = None,
         forwarder_arn: typing.Optional[builtins.str] = None,
+        java_layer_version: typing.Optional[jsii.Number] = None,
         log_level: typing.Optional[builtins.str] = None,
         node_layer_version: typing.Optional[jsii.Number] = None,
         python_layer_version: typing.Optional[jsii.Number] = None,
         site: typing.Optional[builtins.str] = None,
+        source_code_integration: typing.Optional[builtins.bool] = None,
     ) -> None:
         '''
         :param add_layers: 
@@ -803,10 +987,12 @@ class DatadogStrictProps:
         :param extension_layer_version: 
         :param flush_metrics_to_logs: 
         :param forwarder_arn: 
+        :param java_layer_version: 
         :param log_level: 
         :param node_layer_version: 
         :param python_layer_version: 
         :param site: 
+        :param source_code_integration: 
         '''
         if __debug__:
             type_hints = typing.get_type_hints(_typecheckingstub__c0d4909ff321b27042bd7da99817517e719945ec07952fd9fd3a213ccaf8b9d4)
@@ -822,10 +1008,12 @@ class DatadogStrictProps:
             check_type(argname="argument extension_layer_version", value=extension_layer_version, expected_type=type_hints["extension_layer_version"])
             check_type(argname="argument flush_metrics_to_logs", value=flush_metrics_to_logs, expected_type=type_hints["flush_metrics_to_logs"])
             check_type(argname="argument forwarder_arn", value=forwarder_arn, expected_type=type_hints["forwarder_arn"])
+            check_type(argname="argument java_layer_version", value=java_layer_version, expected_type=type_hints["java_layer_version"])
             check_type(argname="argument log_level", value=log_level, expected_type=type_hints["log_level"])
             check_type(argname="argument node_layer_version", value=node_layer_version, expected_type=type_hints["node_layer_version"])
             check_type(argname="argument python_layer_version", value=python_layer_version, expected_type=type_hints["python_layer_version"])
             check_type(argname="argument site", value=site, expected_type=type_hints["site"])
+            check_type(argname="argument source_code_integration", value=source_code_integration, expected_type=type_hints["source_code_integration"])
         self._values: typing.Dict[builtins.str, typing.Any] = {
             "add_layers": add_layers,
             "capture_lambda_payload": capture_lambda_payload,
@@ -846,6 +1034,8 @@ class DatadogStrictProps:
             self._values["flush_metrics_to_logs"] = flush_metrics_to_logs
         if forwarder_arn is not None:
             self._values["forwarder_arn"] = forwarder_arn
+        if java_layer_version is not None:
+            self._values["java_layer_version"] = java_layer_version
         if log_level is not None:
             self._values["log_level"] = log_level
         if node_layer_version is not None:
@@ -854,6 +1044,8 @@ class DatadogStrictProps:
             self._values["python_layer_version"] = python_layer_version
         if site is not None:
             self._values["site"] = site
+        if source_code_integration is not None:
+            self._values["source_code_integration"] = source_code_integration
 
     @builtins.property
     def add_layers(self) -> builtins.bool:
@@ -921,6 +1113,11 @@ class DatadogStrictProps:
         result = self._values.get("forwarder_arn")
         return typing.cast(typing.Optional[builtins.str], result)
 
+    @builtins.property
+    def java_layer_version(self) -> typing.Optional[jsii.Number]:
+        result = self._values.get("java_layer_version")
+        return typing.cast(typing.Optional[jsii.Number], result)
+
     @builtins.property
     def log_level(self) -> typing.Optional[builtins.str]:
         result = self._values.get("log_level")
@@ -941,6 +1138,11 @@ class DatadogStrictProps:
         result = self._values.get("site")
         return typing.cast(typing.Optional[builtins.str], result)
 
+    @builtins.property
+    def source_code_integration(self) -> typing.Optional[builtins.bool]:
+        result = self._values.get("source_code_integration")
+        return typing.cast(typing.Optional[builtins.bool], result)
+
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
@@ -1112,6 +1314,7 @@ class Runtime:
 class RuntimeType(enum.Enum):
     NODE = "NODE"
     PYTHON = "PYTHON"
+    JAVA = "JAVA"
     UNSUPPORTED = "UNSUPPORTED"
 
 
@@ -1259,21 +1462,30 @@ def _typecheckingstub__74e095ab68a1ec6a36ad77e9741c22f8922ea76270d93f498ffa8f784
     api_key: typing.Optional[builtins.str] = None,
     api_key_secret_arn: typing.Optional[builtins.str] = None,
     api_kms_key: typing.Optional[builtins.str] = None,
+    apm_flush_deadline: typing.Optional[typing.Union[builtins.str, jsii.Number]] = None,
     capture_lambda_payload: typing.Optional[builtins.bool] = None,
+    cold_start_trace_skip_libs: typing.Optional[builtins.str] = None,
     create_forwarder_permissions: typing.Optional[builtins.bool] = None,
+    decode_authorizer_context: typing.Optional[builtins.bool] = None,
+    enable_cold_start_tracing: typing.Optional[builtins.bool] = None,
     enable_datadog_logs: typing.Optional[builtins.bool] = None,
     enable_datadog_tracing: typing.Optional[builtins.bool] = None,
     enable_merge_xray_traces: typing.Optional[builtins.bool] = None,
+    enable_profiling: typing.Optional[builtins.bool] = None,
+    encode_authorizer_context: typing.Optional[builtins.bool] = None,
     env: typing.Optional[builtins.str] = None,
     extension_layer_version: typing.Optional[jsii.Number] = None,
     flush_metrics_to_logs: typing.Optional[builtins.bool] = None,
     forwarder_arn: typing.Optional[builtins.str] = None,
     inject_log_context: typing.Optional[builtins.bool] = None,
+    java_layer_version: typing.Optional[jsii.Number] = None,
     log_level: typing.Optional[builtins.str] = None,
+    min_cold_start_trace_duration: typing.Optional[jsii.Number] = None,
     node_layer_version: typing.Optional[jsii.Number] = None,
     python_layer_version: typing.Optional[jsii.Number] = None,
     service: typing.Optional[builtins.str] = None,
     site: typing.Optional[builtins.str] = None,
+    source_code_integration: typing.Optional[builtins.bool] = None,
     tags: typing.Optional[builtins.str] = None,
     version: typing.Optional[builtins.str] = None,
 ) -> None:
@@ -1288,7 +1500,8 @@ def _typecheckingstub__b2299a0a72b8c17837c229cea786d90db2682af81487298b4e2cf18be
 
 def _typecheckingstub__313fba2a998cdf3ba070c09b0db7a32884ad3e5a7bb9eeaf8861202b45695e8e(
     lambda_functions: typing.Sequence[typing.Union[_aws_cdk_aws_lambda_ceddda9d.Function, _aws_cdk_aws_lambda_nodejs_ceddda9d.NodejsFunction, _aws_cdk_aws_lambda_python_alpha_49328424.PythonFunction]],
-    git_commit_sha: builtins.str,
+    git_commit_sha: typing.Optional[builtins.str] = None,
+    git_repo_url: typing.Optional[builtins.str] = None,
 ) -> None:
     """Type checking stubs"""
     pass
@@ -1323,21 +1536,30 @@ def _typecheckingstub__5b78922f591d5e7cd5e1fdd07bf0372e40211fa86d3614124736912ae
     api_key: typing.Optional[builtins.str] = None,
     api_key_secret_arn: typing.Optional[builtins.str] = None,
     api_kms_key: typing.Optional[builtins.str] = None,
+    apm_flush_deadline: typing.Optional[typing.Union[builtins.str, jsii.Number]] = None,
     capture_lambda_payload: typing.Optional[builtins.bool] = None,
+    cold_start_trace_skip_libs: typing.Optional[builtins.str] = None,
     create_forwarder_permissions: typing.Optional[builtins.bool] = None,
+    decode_authorizer_context: typing.Optional[builtins.bool] = None,
+    enable_cold_start_tracing: typing.Optional[builtins.bool] = None,
     enable_datadog_logs: typing.Optional[builtins.bool] = None,
     enable_datadog_tracing: typing.Optional[builtins.bool] = None,
     enable_merge_xray_traces: typing.Optional[builtins.bool] = None,
+    enable_profiling: typing.Optional[builtins.bool] = None,
+    encode_authorizer_context: typing.Optional[builtins.bool] = None,
     env: typing.Optional[builtins.str] = None,
     extension_layer_version: typing.Optional[jsii.Number] = None,
     flush_metrics_to_logs: typing.Optional[builtins.bool] = None,
     forwarder_arn: typing.Optional[builtins.str] = None,
     inject_log_context: typing.Optional[builtins.bool] = None,
+    java_layer_version: typing.Optional[jsii.Number] = None,
     log_level: typing.Optional[builtins.str] = None,
+    min_cold_start_trace_duration: typing.Optional[jsii.Number] = None,
     node_layer_version: typing.Optional[jsii.Number] = None,
     python_layer_version: typing.Optional[jsii.Number] = None,
     service: typing.Optional[builtins.str] = None,
     site: typing.Optional[builtins.str] = None,
+    source_code_integration: typing.Optional[builtins.bool] = None,
     tags: typing.Optional[builtins.str] = None,
     version: typing.Optional[builtins.str] = None,
 ) -> None:
@@ -1358,10 +1580,12 @@ def _typecheckingstub__c0d4909ff321b27042bd7da99817517e719945ec07952fd9fd3a213cc
     extension_layer_version: typing.Optional[jsii.Number] = None,
     flush_metrics_to_logs: typing.Optional[builtins.bool] = None,
     forwarder_arn: typing.Optional[builtins.str] = None,
+    java_layer_version: typing.Optional[jsii.Number] = None,
     log_level: typing.Optional[builtins.str] = None,
     node_layer_version: typing.Optional[jsii.Number] = None,
     python_layer_version: typing.Optional[jsii.Number] = None,
     site: typing.Optional[builtins.str] = None,
+    source_code_integration: typing.Optional[builtins.bool] = None,
 ) -> None:
     """Type checking stubs"""
     pass
